@@ -1,14 +1,14 @@
 import logging
 from functools import reduce
 from itertools import product
-from os import sep, remove
+from os import remove
 from os.path import split, join as path_join, abspath
 
 from click import command, argument, option, style
 from cloudinary import api
 
 from cloudinary_cli.utils.api_utils import query_cld_folder, upload_file, download_file
-from cloudinary_cli.utils.file_utils import walk_dir, delete_empty_dirs
+from cloudinary_cli.utils.file_utils import walk_dir, delete_empty_dirs, get_destination_folder
 from cloudinary_cli.utils.json_utils import print_json
 from cloudinary_cli.utils.utils import logger, run_tasks_concurrently, confirm_action
 
@@ -84,7 +84,6 @@ class SyncDir:
             return False
 
         files_to_push = self.unique_local_file_names | self.out_of_sync_file_names
-
         to_upload = list(filter(lambda x: split(x)[1][0] != ".", files_to_push))
         logger.info(f"Uploading {len(to_upload)} items to Cloudinary folder '{self.remote_dir}'")
 
@@ -96,7 +95,7 @@ class SyncDir:
         }
         uploads = []
         for file in to_upload:
-            folder = path_join(self.remote_dir, sep.join(file.split(sep)[:-1]))
+            folder = get_destination_folder(self.remote_dir, file)
 
             uploads.append((self.local_files[file]['path'], {**options, 'folder': folder}))
 
